pub async fn run(cmd: SchemaCommand) -> Result<()>Expand description
Errors
Returns an error if the schema cannot be fetched, parsed, or migrated.
pub async fn run(cmd: SchemaCommand) -> Result<()>Returns an error if the schema cannot be fetched, parsed, or migrated.